import { ErrorRequestHandler } from 'express';
import { StatusCodes } from 'http-status-codes';
/**
 * Represents an HTTP error that extends the standard Error object.
 * Includes optional status code properties for HTTP response handling.
 *
 * @interface HttpError
 * @extends {Error}
 * @property {StatusCodes} [statusCode] - The HTTP status code for the error response
 * @property {StatusCodes} [status] - Alternative property for HTTP status code
 */
export interface HttpError extends Error {
    statusCode?: StatusCodes;
    status?: StatusCodes;
}
/**
 * Represents the structure of the error returned by the middleware.
 * stacktrace is only included in the response in development mode.
 */
export interface ErrorResponse {
    message: string;
    stacktrace?: string;
}
/**
 * Creates an Express error-handling middleware function.
 *
 * This middleware function handles errors that occur during the processing of requests.
 * It formats the error response and sets the appropriate HTTP status code.
 *
 * @returns {ErrorRequestHandler} An Express error-handling middleware function.
 *
 * @example
 * ```typescript
 * import express from 'express';
 * import { getErrorHandlerMiddleware } from './path/to/this/module';
 *
 * const app = express();
 *
 * // Other middleware and routes
 *
 * // Error handling middleware should be added last
 * app.use(getErrorHandlerMiddleware());
 *
 * app.listen(3000, () => {
 *   console.log('Server is running on port 3000');
 * });
 * ```
 */
export declare function getErrorHandlerMiddleware(): ErrorRequestHandler;
