"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getErrorHandlerMiddleware = getErrorHandlerMiddleware;
const http_status_codes_1 = require("http-status-codes");
/**
 * Creates an Express error-handling middleware function.
 *
 * This middleware function handles errors that occur during the processing of requests.
 * It formats the error response and sets the appropriate HTTP status code.
 *
 * @returns {ErrorRequestHandler} An Express error-handling middleware function.
 *
 * @example
 * ```typescript
 * import express from 'express';
 * import { getErrorHandlerMiddleware } from './path/to/this/module';
 *
 * const app = express();
 *
 * // Other middleware and routes
 *
 * // Error handling middleware should be added last
 * app.use(getErrorHandlerMiddleware());
 *
 * app.listen(3000, () => {
 *   console.log('Server is running on port 3000');
 * });
 * ```
 */
function getErrorHandlerMiddleware() {
    const mapColoniesErrorExpressHandler = (err, req, res, 
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    next) => {
        const errorResponse = {
            message: err.message,
        };
        const responseStatusCode = err.statusCode ?? err.status ?? http_status_codes_1.StatusCodes.INTERNAL_SERVER_ERROR;
        if (responseStatusCode >= http_status_codes_1.StatusCodes.INTERNAL_SERVER_ERROR) {
            //@ts-expect-error pino-http looks for this property for error info
            res.err = err;
            if (process.env.NODE_ENV === 'production') {
                errorResponse.message = (0, http_status_codes_1.getReasonPhrase)(http_status_codes_1.StatusCodes.INTERNAL_SERVER_ERROR);
            }
            else {
                errorResponse.stacktrace = err.stack;
            }
        }
        res.status(responseStatusCode).json(errorResponse);
    };
    return mapColoniesErrorExpressHandler;
}
//# sourceMappingURL=index.js.map